/*
 * SimpleSender.cpp
 *
 *  Demonstrates sending IR codes in standard format with address and command
 *  An extended example for sending can be found as SendDemo.
 *
 *  Copyright (C) 2020-2022  Armin Joachimsmeyer
 *  armin.joachimsmeyer@gmail.com
 *
 *  This file is part of Arduino-IRremote https://github.com/Arduino-IRremote/Arduino-IRremote.
 *
 *  MIT License
 */
#include <Arduino.h>

#define DISABLE_CODE_FOR_RECEIVER // Disables restarting receiver after each send. Saves 450 bytes program memory and 269 bytes RAM if receiving functions are not used.
//#define SEND_PWM_BY_TIMER         // Disable carrier PWM generation in software and use (restricted) hardware PWM.
//#define USE_NO_SEND_PWM           // Use no carrier PWM, just simulate an active low receiver signal. Overrides SEND_PWM_BY_TIMER definition

//#include <Bounce2.h>
//Bounce nextB = Bounce(); // Instantiate a Bounce object
//Bounce repB = Bounce(); // Instantiate a Bounce object
/*
 * This include defines the actual pin number for pins like IR_RECEIVE_PIN, IR_SEND_PIN for many different boards and architectures
 */
#include "PinDefinitionsAndMore.h"
#include <IRremote.hpp> // include the library

void setup() {
    pinMode(LED_BUILTIN, OUTPUT);

    Serial.begin(115200);

    // Just to know which program is running on my Arduino
    Serial.println(F("START " __FILE__ " from " __DATE__ "\r\nUsing library version " VERSION_IRREMOTE));
    Serial.print(F("Send IR signals at pin "));
    Serial.println(IR_SEND_PIN);

    /*
     * The IR library setup. That's all!
     */
//    IrSender.begin(); // Start with IR_SEND_PIN as send pin and if NO_LED_FEEDBACK_CODE is NOT defined, enable feedback LED at default feedback LED pin
    IrSender.begin(DISABLE_LED_FEEDBACK); // Start with IR_SEND_PIN as send pin and disable feedback LED at default feedback LED pin
  //nextB.attach ( 5 , INPUT_PULLUP );
  //nextB.interval( 25 );
  //repB.attach ( 5 , INPUT_PULLUP );
  //repB.interval( 25 );
  pinMode(5, INPUT_PULLUP);
  pinMode(6, INPUT_PULLUP);


}

/*
 * Set up the data to be sent.
 * For most protocols, the data is build up with a constant 8 (or 16 byte) address
 * and a variable 8 bit command.
 * There are exceptions like Sony and Denon, which have 5 bit address.
 */
uint8_t ssDevice = 0x00; //device 16, 0x10
uint8_t sCommand = 0x3F; // standby 12, 0x0C
uint8_t sRepeats = 1;

unsigned long btnRepState = 1; 
unsigned long btnNextState = 1;  
unsigned long btnRepLastState = 1; 
unsigned long btnNextLastState = 1;  
unsigned long btnRepLastDebT;  // the last time the next button was toggled
unsigned long btnNextLastDebT;  // the last time the rep button was toggled
unsigned long debounceDelay = 50;    // the debounce time; increase if the output flickers

bool nextC = false;
bool repC = false;

void loop() {

  
    /*
     * Print current send values
     */
    Serial.println();
    Serial.print(F("Send now: device=0x"));
    Serial.print(ssDevice, HEX);
    Serial.print(F(" command=0x"));
    Serial.print(sCommand, HEX);
    Serial.print(F(", repeats="));
    Serial.print(sRepeats);
    Serial.println();

    Serial.println(F("Send standard RC5"));
    Serial.flush();

        //IrSender.sendNEC(0x78, 0xF, 0);
    IrSender.sendRC5(ssDevice, sCommand, sRepeats);


    delay(500);  // delay must be greater than 5 ms (RECORD_GAP_MICROS), otherwise the receiver sees it as one long signal

    int readbtnNext = digitalRead(5);
    int readbtnRep = digitalRead(6);

    while(nextC == false && repC == false){
      delay(10);
      readbtnNext = digitalRead(5);
      readbtnRep = digitalRead(6);
        //Serial.print(":(");
      if (readbtnNext != btnNextLastState) {
      // reset the debouncing timer
      btnNextLastDebT = millis();
      }

      if (readbtnRep != btnRepLastState) {
      // reset the debouncing timer
      btnRepLastDebT = millis();
      }

      if ((millis() - btnNextLastState) > debounceDelay) {
      // whatever the reading is at, it's been there for longer than the debounce
      // delay, so take it as the actual current state:

        // if the button state has changed:
        if (readbtnNext != btnNextLastState) {
          btnNextState = readbtnNext;

          // only toggle the LED if the new button state is HIGH
          if (btnNextState == LOW) {
            nextC = true;
            Serial.println("nextC");

          }
        }
      }

      if ((millis() - btnRepLastState) > debounceDelay) {
      // whatever the reading is at, it's been there for longer than the debounce
      // delay, so take it as the actual current state:

        // if the button state has changed:
        if (readbtnRep != btnRepLastState) {
          btnRepState = readbtnRep;

          // only toggle the LED if the new button state is HIGH
          if (btnRepState == LOW) {
            repC = true;
          }
        }
      }


    }

    if ( nextC) {
      // do next command or device
      sCommand = sCommand + 0x01;
      //ssDevice = ssDevice + 0x01;
      nextC = false;
    }
    else{
      if ( repC) {
      // do nothing continue in loop
      repC = false;
    }

    }
}
